==> soliq_id-1.2.16.tar.gz: lib/soliq_id.dart <==
library soliq_id;

import 'dart:developer';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:soliq_id/src/data/bloc/soliq_id_bloc.dart';
import 'package:soliq_id/src/data/di/di_container.dart';
import 'package:soliq_id/src/data/storages/preference.dart';

import 'src/data/repository/soliq_id_repository.dart';
import 'src/screens/face_id_signin.dart';

import 'localizations_util.dart';

List<CameraDescription> cameras = [];
Preference? pref;

class SoliqId extends StatefulWidget {
  const SoliqId({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid,
  }) : super(key: key);
  final pinfl;
  final LocalizationType localizationType;
  final String guid;

  @override
  State<SoliqId> createState() => _SoliqIdState();
}

class _SoliqIdState extends State<SoliqId> {
  Preference preference = Preference();

  @override
  void initState() {
    super.initState();
    initDi();
    getGuid();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<void>(
      future: initDi(),
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.done) {
          final soliqIdBloc = SoliqIdBloc(
            getIt<SoliqIdRepository>(),
          );
          log("Bloc of created $soliqIdBloc");
          return BlocProvider(
            create: (_) => soliqIdBloc,
            child: FaceIdSignIn(
              pinfl: widget.pinfl,
              localizationType: widget.localizationType,
              guid: widget.guid,
            ),
          );
        } else {
          return const CircularProgressIndicator();
        }
      },
    );
  }

  Future<void> getGuid() async {
    final locale = getLocalizationType(
      widget.localizationType,
    );
    final preference = Preference();
    await preference.setLang(locale);
    await preference.setGUID(widget.guid);
    cameras = await availableCameras();

    pref = await preference.init();
  }

  @override
  void dispose() async {
    await preference.removeGUID();
    super.dispose();
  }
}

==> soliq_id-1.2.20.tar.gz: lib/soliq_id.dart <==
library soliq_id;

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:injectable/injectable.dart';
import 'package:soliq_id/soliq_id.config.dart';
import 'package:soliq_id/src/data/bloc/soliq_id_bloc.dart';
import 'package:soliq_id/src/data/storages/preference.dart';

import 'src/data/di/di_container.dart';
import 'src/data/repository/soliq_id_repository.dart';
import 'src/screens/face_id_signin.dart';

import 'localizations_util.dart';

List<CameraDescription> cameras = [];
Preference? pref;

final getIt = GetIt.instance;

@InjectableInit()
Future<void> initDi() async {
  getIt.init();
  await getIt.allReady();
}

Future<void> disposeDi() async {
  await getIt.reset();
}

class SoliqId extends StatefulWidget {
  const SoliqId({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid,
  }) : super(key: key);
  final pinfl;
  final LocalizationType localizationType;
  final String guid;

  @override
  State<SoliqId> createState() => _SoliqIdState();
}

class _SoliqIdState extends State<SoliqId> {
  Preference preference = Preference();

  @override
  void initState() {
    super.initState();
    initDi();
    getGuid();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<void>(
      future: initDi(),
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.done) {
          return BlocProvider(
            create: (_) => SoliqIdBloc(
              getIt<SoliqIdRepository>(),
            ),
            child: FaceIdSignIn(
              pinfl: widget.pinfl,
              localizationType: widget.localizationType,
              guid: widget.guid,
            ),
          );
        } else {
          return const CircularProgressIndicator();
        }
      },
    );
  }

  Future<void> getGuid() async {
    final locale = getLocalizationType(
      widget.localizationType,
    );
    final preference = Preference();
    await preference.setLang(locale);
    await preference.setGUID(widget.guid);
    cameras = await availableCameras();

    pref = await preference.init();
    await Future.delayed(const Duration(seconds: 2));
  }

  @override
  void dispose() async {
    await preference.removeGUID();
    super.dispose();
  }
}
